@@ -8,13 +8,16 @@ from typing import BinaryIO
 from typing import Dict
 from typing import Union
 
-from barcode.codex import Code128
-from barcode.codex import Code39
-from barcode.codex import Gs1_128
+from barcode.codabar import CODABAR
 from barcode.codex import PZN
-from barcode.ean import EAN13
-from barcode.ean import EAN14
+from barcode.codex import Code39
+from barcode.codex import Code128
+from barcode.codex import Gs1_128
 from barcode.ean import EAN8
+from barcode.ean import EAN8_GUARD
+from barcode.ean import EAN13
+from barcode.ean import EAN13_GUARD
+from barcode.ean import EAN14
 from barcode.ean import JAN
 from barcode.errors import BarcodeNotFoundError
 from barcode.isxn import ISBN10
@@ -26,7 +29,9 @@ from barcode.version import version  # noqa: F401
 
 __BARCODE_MAP = {
     "ean8": EAN8,
+    "ean8-guard": EAN8_GUARD,
     "ean13": EAN13,
+    "ean13-guard": EAN13_GUARD,
     "ean": EAN13,
     "gtin": EAN14,
     "ean14": EAN14,
@@ -43,6 +48,8 @@ __BARCODE_MAP = {
     "code128": Code128,
     "itf": ITF,
     "gs1_128": Gs1_128,
+    "codabar": CODABAR,
+    "nw-7": CODABAR,
 }
 
 PROVIDED_BARCODES = list(__BARCODE_MAP)
@@ -58,18 +65,14 @@ def get(name, code=None, writer=None, options=None):
         is returned.
     :param Writer writer: An alternative writer to use when generating the
         barcode.
-    :param dict options: Aditional options to be passed on to the barcode when
+    :param dict options: Additional options to be passed on to the barcode when
         generating.
     """
-
     options = options or {}
     try:
         barcode = __BARCODE_MAP[name.lower()]
     except KeyError:
-        raise BarcodeNotFoundError(
-            "The barcode {!r} you requested is not known.".format(name)
-        )
-
+        raise BarcodeNotFoundError(f"The barcode {name!r} you requested is not known.")
     if code is not None:
         return barcode(code, writer, **options)
     else:
